Crate bpm_ocr

Crate bpm_ocr 

Modules

debug
models

Structs

BloodPressureReadingExtractor

Functions

get_reading_from_buffer
Attempts to extract a blood pressure reading from a byte buffer containing a photo file of a blood pressure monitor screen
get_reading_from_file
Attempts to extract a blood pressure reading from a photo file of a blood pressure monitor screen