Structs
- NoDebug
- Unsafe
Temp Folder Debugger - Named unsafe as if the same debugger instance is used across different executions of BloodPressureReadingExtractor then the files will be overwritten with new values and if it is used across concurrent executions then the files may be corrupted or an error may be thrown. A new BloodPressureReadingExtractor should be constructed for each run when using this debugger.