get_reading_from_buffer

Function get_reading_from_buffer 

pub fn get_reading_from_buffer<T: BpmOcrDebugOutputter>(
    file_contents: Vec<u8>,
    debugger: DebuggerTrace<T>,
) -> Result<BloodPressureReading, ProcessingError>
Attempts to extract a blood pressure reading from a byte buffer containing a photo file of a blood pressure monitor screen

  • filename - the byte buffer with the photo file
  • debugger - the debugger trace session to output debug images with