pub struct BloodPressureReadingExtractor<T: BpmOcrDebugOutputter> { /* private fields */ }Implementations
Sourceimpl<T: BpmOcrDebugOutputter> BloodPressureReadingExtractor<T>
impl<T: BpmOcrDebugOutputter> BloodPressureReadingExtractor<T>
pub fn new(debugger: T) -> Self
Sourcepub fn get_reading_from_file(
&self,
filename: &str,
) -> Result<BloodPressureReading, ProcessingError>
pub fn get_reading_from_file( &self, filename: &str, ) -> Result<BloodPressureReading, ProcessingError>
Attempts to extract a blood pressure reading from a photo file of a blood pressure monitor screen
filename- the path to the photo file
Sourcepub fn get_reading_from_buffer(
&self,
file_contents: Vec<u8>,
) -> Result<BloodPressureReading, ProcessingError>
pub fn get_reading_from_buffer( &self, file_contents: Vec<u8>, ) -> Result<BloodPressureReading, ProcessingError>
Attempts to extract a blood pressure reading from a byte buffer containing a photo file of a blood pressure monitor screen
filename- the byte buffer with the photo file