pub struct UnsafeTempFolderDebugger { /* private fields */ }Expand description
Named unsafe as if the same debugger instance is used across different executions of BloodPressureReadingExtractor then the files will be overwritten with new values and if it is used across concurrent executions then the files may be corrupted or an error may be thrown. A new BloodPressureReadingExtractor should be constructed for each run when using this debugger.
This debugger writes the debug image files to the system temporary folder. The folder lives inside bpm-ocr/${folder_name}
Implementations
Sourceimpl UnsafeTempFolderDebugger
impl UnsafeTempFolderDebugger
pub fn using_timestamp_folder_name(debug_enabled: bool) -> Self