pub fn get_reading_from_buffer<T: BpmOcrDebugOutputter>(
file_contents: Vec<u8>,
debugger: DebuggerTrace<T>,
) -> Result<BloodPressureReading, ProcessingError>Expand description
Attempts to extract a blood pressure reading from a byte buffer containing a photo file of a blood pressure monitor screen
filename- the byte buffer with the photo filedebugger- the debugger trace session to output debug images with